# Copyright Alper KUM 2023, BSD 3-Clause license
"""
Colorama_EX ANSI_EX Module
This module generates 256-color ANSI character codes to print colors to terminals, which is an upgrade over standard Colorama's 16-color codes.
"""

#FORECODE = '\x1b[38;5;'
BACKCODE = '\x1b[48;5;'

def code_to_chars_ex(code):
    return BACKCODE + str(code) + 'm'


class AnsiBackCodes_EX(object):
    def __init__(self):
        # the subclasses declare class attributes which are numbers.
        # Upon instantiation we define instance attributes, which are the same
        # as the class attributes but wrapped with the ANSI escape sequence
        for name in dir(self):
            if not name.startswith('_'):
                value = getattr(self, name)
                setattr(self, name, code_to_chars_ex(value))

class AnsiBack(AnsiBackCodes_EX):
    BLACK = 0
    RED = 1
    GREEN = 2
    YELLOW = 3
    BLUE = 4
    MAGENTA = 5
    CYAN = 6
    WHITE = 7
    LIGHTBLACK = 8
    LIGHTRED = 9
    LIGHTGREEN = 10
    LIGHTYELLOW = 11
    LIGHTBLUE = 12
    LIGHTMAGENTA = 13
    LIGHTCYAN = 14
    LIGHTWHITE = 15

class AnsiBack_EX(AnsiBackCodes_EX):
    BLACK = 16
    STRATOSBLUE = 17
    NAVYBLUE = 18
    NAVYBLUE_EX = 19
    DARKBLUE = 20
    BLUE = 21
    DEEPFIR = 22
    DEEPTEAL = 23
    MIDNIGHTBLUE = 24
    SMALT = 25
    KLEINBLUE = 26
    RIBBONBLUE = 27
    CAMARONEGREEN = 28
    FUNGREEN = 29
    BLUESTONE = 30
    BAHAMABLUE = 31
    SCIENCEBLUE = 32
    RIBBONBLUE_EX = 33
    LAURELGREEN = 34
    FUNGREEN_EX = 35
    GREENHAZE = 36
    PERSIANGREEN = 37
    PACIFICBLUE = 38
    AZUREBLUE = 39
    GREEN = 40
    MALACHITE = 41
    JADEGREEN = 42
    CARRIBEANGREEN = 43
    ROBINBLUE = 44
    CYAN = 45
    GREEN_EX = 46
    SWEETGREEN = 47
    SPRINGGREEN = 48
    SPRINGGREEN_EX = 49
    TURQUISE = 50
    CYAN_EX = 51
    TEMPTRESS = 52
    BAROSSA = 53
    CHRISTALLE = 54
    INDIGO = 55
    INDIGO_EX = 56
    LIGHTINDIGO_EX = 57
    MADRAS = 58
    MINESHAFT = 59
    RHINOBLUE = 60
    SAPPHIRE = 61
    GOVERNORBLUE = 62
    GOVERNORBLUE_EX = 63
    VERDUNGREEN = 64
    KILLARNEYGREEN = 65
    CASALGREEN = 66
    AZUREGREEN = 67
    MARINER = 68
    DODGERBLUE = 69
    LIMEADE = 70
    APPLEGREEN = 71
    SEAGREEN = 72
    LOCHINVAR = 73
    CURIOUSBLUE = 74
    DODGERBLUE_EX = 75
    HARLEQUIN = 76
    APPLEGREEN_EX = 77
    EMERALDGREEN = 78
    SHAMROCK = 79
    GREENTURQUISE = 80
    LIGHTDODGER_EX = 81
    HARLEQUIN_EX = 82
    LIGHTHARLEQUIN_EX = 83
    SCREAMINGREEN = 84
    SPRINGGREEN = 85
    BRIGHTTURQUISE = 86
    BRIGHTTURQUISE_EX = 87
    LONESTARRED = 88
    TYRIANPURPLE = 89
    POMPADOUR = 90
    PURPLE = 91
    BRIGHTPURPLE = 92
    ELECTRICVIOLET = 93
    NUTMEGWOOD = 94
    BUCCANEER = 95
    COSMIC = 96
    ROYALPURPLE = 97
    PURPLEHEART = 98
    ELECTRICVIOLET_EX = 99
    VERDUNGREEN = 100
    COSTADELSOL = 101
    DOVEGRAY = 102
    KIMBERLY = 103
    MARGUERITEBLUE = 104
    CORNFLOWERBLUE = 105
    LIMEADE = 106
    APPLE = 107
    HIGHLANDGREEN = 108
    PATINA = 109
    DANUBE = 110
    MALIBUBLUE = 111
    LIMEADE_EX = 112
    ATLANTISGREEN = 113
    MANTISGREEN = 114
    EMERALD = 115
    DOWNY = 116
    MALIBUBLUE_EX = 117
    BRIGHTGREEN = 118
    BRIGHTGREEN_EX = 119
    SCREAMINGREEN_EX = 120
    SCREAMINGREENBLUE = 121
    AQUAMARINE = 122
    AQUAMARINE_EX = 123
    REDBERRY = 124
    PAPRIKA = 125
    FRESHEGGPLANT = 126
    FLIRT = 127
    ELECTRICVIOLETLIGHT = 128
    ELECTRICVIOLETLIGHT_EX = 129
    OREGON = 130
    STILETTO = 131
    ROUGE = 132
    PLUM = 133
    PURPLEHEART = 134
    BRIGHTELECTRICVIOLET = 135
    CHELSEAGEM = 136
    POTTERSCLAY = 137
    COPPERROSE = 138
    STRIKEMASTER = 139
    AMETHYST = 140
    HELIOTROPE = 141
    OLIVE = 142
    SYCAMORE = 143
    AVOCADO = 144
    DUSTYGRAY = 145
    BLUEBELL = 146
    MELROSE = 147
    PISTACHIOGREEN = 148
    ATLANTISGREEN_EX = 149
    WILDWILLOWGREEN = 150
    DEYORKGREEN = 151
    SINBADBLUE = 152
    ANAKIWABLUE = 153
    CHARTREUSE = 154
    GREENYELLOW = 155
    LIGHTSCREAMINGREEN = 156
    MINTGREEN = 157
    GREENAQUAMARINE = 158
    ANAKIWABLUE_EX = 159
    GUARDSMANRED = 160
    MONZARED = 161
    LIPSTICK = 162
    CERISERED = 163
    PIZZAZZPURPLE = 164
    LIGHTELECTRICVIOLET = 165
    GRENADIER = 166
    PERSIANRED = 167
    HIBISCUSRED = 168
    MEDIUMVIOLET = 169
    FUCHSIA = 170
    HELIOTROPE_EX = 171
    TENNORANGE = 172
    TUSCANY = 173
    CHESTNUTROSE = 174
    HOPBUSH = 175
    FUCHSIA_EX = 176
    LIGHTHELIOTROPE = 177
    BUDDHAGOLD = 178
    HOKEYPOKEY = 179
    ANTIQUEBRASS = 180
    EUNRY = 181
    LILAC = 182
    MAUVEPURPLE = 183
    RIOGRANDE = 184
    EARLSGREEN = 185
    LASER = 186
    PINEGLADE = 187
    SILVER = 188
    PERIWINKLE = 189
    ELECTRICLIME = 190
    GREENYELLOW_EX = 191
    CANARYGREEN = 192
    REEFGREEN = 193
    SNOWYMINT = 194
    ONAHAUBLUE = 195
    RED = 196
    TORCHRED = 197
    ROSE = 198
    CERISE = 199
    PIZZAZZPURPLE_EX = 200
    MAGENTA = 201
    SCARLETORANGE = 202
    REDORANGE = 203
    RADICALRED = 204
    STRAWBERRY = 205
    RAZZLEDAZZLE = 206
    RAZZLEDAZZLE_EX = 207
    BLAZEORANGE = 208
    OUTRAGEOUSORANGE = 209
    BITTERSWEET = 210
    HOTPINK = 211
    HOTPINK_EX = 212
    PINKFLAMINGO = 213
    ORANGEPEEL = 214
    NEONCARROT = 215
    ATOMICTANGERINE = 216
    MONALISA = 217
    CARNATIONPINK = 218
    LAVENDERROSE = 219
    SUPERNOVA = 220
    SUNGLOW = 221
    GOLDENTAINOI = 222
    PEACHORANGE = 223
    YOURPINK = 224
    PINKLACE = 225
    YELLOW = 226
    GOLDENFIZZ = 227
    LASERLEMON = 228
    PALECANARY = 229
    CREAM = 230
    WHITE = 231

class AnsiBack_Gray(AnsiBackCodes_EX):
    BLACK = 232
    GRAY1 = 233
    GRAY2 = 234
    GRAY3 = 235
    GRAY4 = 236
    GRAY5 = 237
    GRAY6 = 238
    GRAY7 = 239
    GRAY8 = 240
    GRAY9 = 241
    GRAY10 = 242
    GRAY11 = 243
    GRAY12 = 244
    GRAY13 = 245
    GRAY14 = 246
    GRAY15 = 247
    GRAY16 = 248
    GRAY17 = 249
    GRAY18 = 250
    GRAY19 = 251
    GRAY20 = 252
    GRAY21 = 253
    GRAY22 = 254
    WHITE = 255

    GRAYSCALE = [BLACK,GRAY1,GRAY2,GRAY3,GRAY4,GRAY5,GRAY6,GRAY7,GRAY8,GRAY9,GRAY10,GRAY11,GRAY12,GRAY13,GRAY14,GRAY15,GRAY16,GRAY17,GRAY18,GRAY19,GRAY20,GRAY21,GRAY22,WHITE]

Back = AnsiBack()
Back_EX = AnsiBack_EX()
Back_Gray = AnsiBack_Gray()